@@ -17,6 +17,7 @@
 
 from __future__ import absolute_import
 from __future__ import print_function
+from __future__ import division
 
 __author__                      = "Perry Kundert"
 __email__                       = "perry@hardconsulting.com"
@@ -55,10 +56,6 @@ from   cpppo.server import network
 
 from .parser import *
 
-if __name__ == "__main__":
-    logging.basicConfig( **cpppo.log_cfg )
-    #logging.getLogger().setLevel( logging.DETAIL )
-
 log				= logging.getLogger( "enip.dev" )
 
 # 
